@@ -38,21 +38,12 @@ class ProcfileWatcherTest(TestCase):
         plugin.add_watcher(name=name, cmd=cmd)
         plugin.circus_client.call.assert_called_with(options)
 
-    def test_remove_watcher(self):
+    def test_remove_watchers(self):
         plugin = ProcfileWatcher("", "", 1)
         plugin.call = Mock()
-        name = "name"
-        plugin.remove_watcher(name=name)
-        plugin.call.assert_called_with("rm", name=name)
-
-    def test_commands(self):
-        plugin = ProcfileWatcher("", "", 1)
-        result = Mock()
-        result.return_value = {"statuses": {}}
-        plugin.call = result
-        procfile = Procfile('web: gunicorn -b 0.0.0.0:8080 abyss.wsgi\n')
-        to_add, to_remove = plugin.commands(procfile)
-        plugin.call.assert_called_with("status")
+        plugin.call.return_value = {"statuses": {"name": ""}}
+        plugin.remove_watchers()
+        plugin.call.assert_called_with("rm", name="name")
 
     def test_envs(self):
         plugin = ProcfileWatcher("", "", 1)
